@@ -56,67 +56,66 @@ extern "C" {
 #define XKL_CONFIG_ITEM_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), XKL_TYPE_CONFIG_ITEM, XklConfigItemClass))
 
 /**
+ * _XklConfigItem:
+ * @parent: The superclass object
+ * @name: The configuration item name. Corresponds to XML element "name".
+ * @short_description: The configuration item short description. Corresponds to XML element "shortDescription".
+ * @description: The configuration item description. Corresponds to XML element "description".
+ *
  * The configuration item. Corresponds to XML element "configItem".
  */
 	struct _XklConfigItem {
-/**
- * The superclass object
- */
 		GObject parent;
-/**
- * The configuration item name. Corresponds to XML element "name".
- */
+
 		gchar name[XKL_MAX_CI_NAME_LENGTH];
 
-/**
- * The configuration item short description. Corresponds to XML element "shortDescription".
- */
 		gchar short_description[XKL_MAX_CI_DESC_LENGTH];
 
-/**
- * The configuration item description. Corresponds to XML element "description".
- */
 		gchar description[XKL_MAX_CI_DESC_LENGTH];
 	};
 
 /**
+ * XCI_PROP_ALLOW_MULTIPLE_SELECTION:
  * Extra property for the XklConfigItem, defining whether the group allows multiple selection
  */
 #define XCI_PROP_ALLOW_MULTIPLE_SELECTION "allowMultipleSelection"
 
 /**
+ * XCI_PROP_VENDOR:
  * Extra property for the XklConfigItem, defining the vendor (used for models)
  */
 #define XCI_PROP_VENDOR "vendor"
 
 /**
+ * XCI_PROP_COUNTRY_LIST:
  * Extra property for the XklConfigItem, defining the list of countries (used for layouts/variants)
  */
 #define XCI_PROP_COUNTRY_LIST "countryList"
 
 /**
+ * XCI_PROP_LANGUAGE_LIST:
  * Extra property for the XklConfigItem, defining the list of languages (used for layouts/variants)
  */
 #define XCI_PROP_LANGUAGE_LIST "languageList"
 
 /**
+ * XCI_PROP_EXTRA_ITEM:
  * Extra property for the XklConfigItem, defining whether that item is exotic(extra)
  */
 #define XCI_PROP_EXTRA_ITEM "extraItem"
 
 /**
+ * _XklConfigItemClass:
+ * @parent_class: The superclass
  * The XklConfigItem class, derived from GObject
  */
 	struct _XklConfigItemClass {
-    /**
-     * The superclass
-     */
 		GObjectClass parent_class;
 	};
 
 /**
  * xkl_config_item_get_type:
- * 
+ *
  * Get type info for XklConfigItem
  *
  * Returns: GType for XklConfigItem
@@ -133,8 +132,16 @@ extern "C" {
 	extern XklConfigItem *xkl_config_item_new(void);
 
 /**
- * xkl_config_item_set_name:
+ * xkl_config_item_get_name:
+ * @item: the XklConfigItem object
  *
+ * Returns: The @name field of a XklConfigItem. This is mostly useful for
+ * language bindings, in C you can manipulate the member directly.
+ */
+extern const gchar * xkl_config_item_get_name(XklConfigItem * item);
+
+/**
+ * xkl_config_item_set_name:
  * @item: the XklConfigItem object to be changed
  * @name: (transfer none) (allow-none): Name (max. 32 characters); can be NULL.
  *
@@ -145,8 +152,16 @@ extern "C" {
 					     const gchar * name);
 
 /**
- * xkl_config_item_set_short_description:
+ * xkl_config_item_get_short_description:
+ * @item: the XklConfigItem object
  *
+ * Returns: The @short_description field of a XklConfigItem. This is mostly useful for
+ * language bindings, in C you can manipulate the member directly.
+ */
+extern const gchar * xkl_config_item_get_short_description(XklConfigItem * item);
+
+/**
+ * xkl_config_item_set_short_description:
  * @item: the XklConfigItem object to be changed
  * @short_description: (transfer none) (allow-none): Short Description (max. 10
  *        characters); can be NULL.
@@ -157,8 +172,16 @@ extern "C" {
 	extern void xkl_config_item_set_short_description(XklConfigItem * item,
 							  const gchar * short_description);
 /**
- * xkl_config_item_set_description:
+ * xkl_config_item_get_description:
+ * @item: the XklConfigItem object
  *
+ * Returns: The @description field of a XklConfigItem. This is mostly useful for
+ * language bindings, in C you can manipulate the member directly.
+ */
+extern const gchar * xkl_config_item_get_description(XklConfigItem * item);
+
+/**
+ * xkl_config_item_set_description:
  * @item: the XklConfigItem object to be changed
  * @description: (transfer none) (allow-none): Description (max. 192
  *        characters); can be NULL.
